AppConfig class

Constructors

AppConfig({required String baseUrl, Flavor flavor = Flavor.preprod})
AppConfig.create({String baseUrl = "", Flavor flavor = Flavor.preprod})
factory
AppConfig.fromJson(Map<String, dynamic> json)
factory

Properties

baseUrl String
getter/setter pair
flavor Flavor
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared AppConfig
getter/setter pair

Static Methods

loadConfig(Flavor flavor) Future