ConfirmUserDataRouteArgs class

Constructors

ConfirmUserDataRouteArgs({Key? key, required String partnerName, required String? type, String? amount, int? articleTarifId, int? articleId})
const

Properties

amount String?
final
articleId int?
final
articleTarifId int?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
final
partnerName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited