InAppPurchaseUtils class

Constructors

InAppPurchaseUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

onError ↔ dynamic Function(String)?
getter/setter pair
onPurchaseSuccess ↔ dynamic Function(PurchaseDetails)?
getter/setter pair
products List<ProductDetails>
getter/setter pair

Static Methods

buy(ProductDetails product) Future<void>
Acheter un abonnement
dispose() → void
Nettoyer
init() Future<bool>
Initialiser
restore() Future<void>
Restaurer les achats

Constants

monthlyId → const String
monthlyIdIos → const String
yearlyId → const String
yearlyIdIos → const String