PrefUtils class abstract

Implementers

Constructors

PrefUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getClient() Client?
getIsFirstTime() bool
getPages() List<PageResponse>?
getStoreToken() String
getSubscriptions() List<Subscription>?
getToken() String
logout() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeClient() → void
removeIsFirstTime() → void
removePages() → void
removeStoreToken() → void
removeSubscriptions() → void
removeToken() → void
setClient(Client? client) → void
setIsFirstTime(bool isFirstTime) → void
setPages(List<PageResponse>? pages) → void
setStoreToken(String token) → void
setSubscriptions(List<Subscription>? subscriptions) → void
setToken(String token) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited