CustomDropdown<T> class

Inheritance

Constructors

CustomDropdown({Key? key, required String hint, required List<T> items, required String displayField(T), Widget? prefixIcon, required void onChanged(T?), Color borderColor = Colors.black, String? validator(T?)?, Color backgroundColor = Colors.white, T? firstValue, bool label = false, InputBorder? border, bool readOnly = false})
const

Properties

backgroundColor Color
final
border InputBorder?
final
borderColor Color
final
displayField String Function(T)
final
firstValue → T?
final
hashCode int
The hash code for this object.
no setterinherited
hint String
final
items List<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label bool
final
onChanged → void Function(T?)
final
prefixIcon Widget?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator String? Function(T?)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CustomDropdownState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited