SearchTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SearchTextField
Constructors
- SearchTextField({Key? key, required TextEditingController controller, required String textFieldHint, required bool isRequired, Function? onTap, bool readOnly = false, bool enabled = true, int linesNumber = 1, TextInputType keyboardType = TextInputType.emailAddress, bool isWrong = false, Color backgroundColor = Colors.white, Color borderColor = empty, Widget? suffixIcon, Widget? prefixIcon, String? validator(String?)?, bool isPasswordField = false, dynamic onChanged(String)?})
-
const
Properties
- backgroundColor → Color
-
final
- borderColor → Color
-
final
- controller → TextEditingController
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPasswordField → bool
-
final
- isRequired → bool
-
final
- isWrong → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType
-
final
- linesNumber → int
-
final
- onChanged → dynamic Function(String)?
-
final
- onTap → Function?
-
final
- prefixIcon → Widget?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixIcon → Widget?
-
final
- textFieldHint → String
-
final
- validator → String? Function(String?)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SearchTextField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited