ClientInfo class

Annotations
  • @JsonSerializable.new()

Constructors

ClientInfo({required int? id, required int? clientId, required String? deviceId, required String? os, String? source, required String? lastLoginMethod, required ClientDetails? client})
ClientInfo.fromJson(Map<String, dynamic> json)
factory

Properties

client ClientDetails?
final
clientId int?
final
deviceId String?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
lastLoginMethod String?
final
os String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited