Payment class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- countryId → int?
-
final
- countryPaymentsMethodsGratuite → int?
-
final
- countryPaymentsMethodsIcon → String?
-
final
- countryPaymentsMethodsId → int?
-
final
- countryPaymentsMethodsModule → String?
-
final
- countryPaymentsMethodsType → int?
-
final
- desc → String?
-
final
- entryBy → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited