Store class

Annotations
  • @JsonSerializable.new()

Constructors

Store({required int? storeId, required String? storeSlug, required String? storeName, required String? storeDesc, required String? storeMail, required int? storeActive, required int? storeFeatured, required int? storeMobile, required String? storeWebsite, required String? storeFacebook, required String? storeInstagram, required int? durationUntilAlertAgain, required int? showIgnore, required int? showLater, required int? barrierDismissible})
Store.fromJson(Map<String, dynamic> json)
factory

Properties

barrierDismissible int?
final
durationUntilAlertAgain int?
final
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIgnore int?
final
showLater int?
final
storeActive int?
final
storeDesc String?
final
storeFacebook String?
final
storeFeatured int?
final
storeId int?
final
storeInstagram String?
final
final
storeMail String?
final
storeMobile int?
final
final
storeName String?
final
storeSlug String?
final
storeWebsite String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited