StoreResponse class

Annotations
  • @JsonSerializable.new()

Constructors

StoreResponse({Informations? informations, Store? store, Token? token, List<Subscription>? subscriptions})
StoreResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
informations Informations?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store Store?
final
subscriptions List<Subscription>?
final
token Token?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited