Subscription class

Annotations
  • @JsonSerializable.new()

Constructors

Subscription({required int? abonnementId, required String? abonnementNom, required String? abonnementIcon, required String? abonnementDesc, required int? abonnementDuree, required int? countryId, required int? abonnementStore, required String? entryBy, required List<Tarif>? tarifs})
Subscription.fromJson(Map<String, dynamic> json)
factory

Properties

abonnementDesc String?
final
abonnementDuree int?
final
abonnementIcon String?
final
abonnementId int?
final
abonnementNom String?
final
abonnementStore int?
final
countryId int?
final
entryBy String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tarifs List<Tarif>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited