Tarif class

Annotations
  • @JsonSerializable.new()

Constructors

Tarif({int? id, int? abonnementId, int? abonnementTarifsDuration, int? abonnementTarifsFrequence, int? price, int? cout, int? abonnementTarifsPriority, int? countryPaymentsMethodsId, String? entryBy, Payment? payment, String? googleProductId, String? appleProductId})
Tarif.fromJson(Map<String, dynamic> json)
factory

Properties

abonnementId int?
final
abonnementTarifsDuration int?
final
abonnementTarifsFrequence int?
final
abonnementTarifsPriority int?
final
appleProductId String?
final
countryPaymentsMethodsId int?
final
cout int?
final
entryBy String?
final
googleProductId String?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
payment Payment?
final
price int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited