ExternalAuthRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ExternalAuthRequest({required int externalClientId, String? clientPrenom, String? clientNom, String? clientTelephone, String? clientGender, int? clientAge, required String clientPhoneId, required String clientPhoneOs, required String clientEmail, required int storeId, required bool isSubscribed, int? externalClientAbonnementId, int? abonnementId, int? tarifId, String? clientAbonnementCreation, String? clientAbonnementExpiration})
ExternalAuthRequest.fromJson(Map<String, dynamic> json)
factory

Properties

abonnementId int?
final
clientAbonnementCreation String?
final
clientAbonnementExpiration String?
final
clientAge int?
final
clientEmail String
final
clientGender String?
final
clientNom String?
final
clientPhoneId String
final
clientPhoneOs String
final
clientPrenom String?
final
clientTelephone String?
final
externalClientAbonnementId int?
final
externalClientId int
final
hashCode int
The hash code for this object.
no setterinherited
isSubscribed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeId int
final
tarifId int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited