PrivilegesRemoteDataSource class abstract

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCartridges() Future<AppResponse<List<CartridgesResponse>>>
getPartnerById(PartnerByIdRequest request) Future<AppResponse<PartnerResponse>>
getPartnerCategory(PartnerCategoryRequest request) Future<AppResponse<List<PartnerCategory>>>
getPartners(PartnerRequest request) Future<AppResponse<PromotionResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchPartners(SearchPartnerRequest request) Future<AppResponse<PromotionResponse>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited