Location class

Annotations
  • @JsonSerializable.new()

Constructors

Location({required int? partnerId, required int? partnerLocationId, required String? partnerLocationNom, required String? partnerLocationGps, required String? partnerLocationAddr, required int? partnerLocationState, required String? partnerCategoryColor})
Location.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
partnerCategoryColor String?
final
partnerId int?
final
partnerLocationAddr String?
final
partnerLocationGps String?
final
partnerLocationId int?
final
partnerLocationNom String?
final
partnerLocationState int?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited