PartnerResponse class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

PartnerResponse({required Partner? partner, required List<Promotion>? promotions, required List<Location>? locations, required List<Article>? articles})
PartnerResponse.fromJson(Map<String, dynamic> json)
factory

Properties

articles List<Article>?
final
hashCode int
The hash code for this object.
no setterinherited
locations List<Location>?
final
partner Partner?
final
promotions List<Promotion>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited