Promotion class

Annotations
  • @JsonSerializable.new()

Constructors

Promotion({required int? promotionId, required int? partnerId, required String? promotionTitle, required String? promotionDesc, required int? promotionDiscountType, required String? promotionDiscount, required String? promotionDateStart, required String? promotionDateEnd, required String? promotionStores, required int? promotionActive, required int? promotionCumulable, required int? useCodes, required int? webScan, required String? createdAt, required String? updatedAt, required String? entryBy, required int? stockMin, required int? promotionSource, required String? promotionType, List<UploadedPdf>? uploadedPdf, String? passPrice, String? oldPassPrice, String? passTitle, String? passConditions, String? passWithQrcode, String? passWithBarcode, String? passSubTitle, String? passShowValidity, String? passShowPrice, String? passPdfTitle, String? passEmailTemplate, String? passShowSubTitle, required int? isPremium, dynamic premiumQuotas, dynamic premiumQuotasPeriod, String? promotionWay, String? promotionCondition, List<String>? cumulativeTextPromotion, String? promotionSiteLink, List<Meta>? metas, String? promotionIcon, String? promotionReducceType})
Promotion.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String?
final
cumulativeTextPromotion List<String>?
final
entryBy String?
final
hashCode int
The hash code for this object.
no setterinherited
isPremium int?
final
metas List<Meta>?
final
oldPassPrice String?
final
partnerId int?
final
passConditions String?
final
passEmailTemplate String?
final
final
passPdfTitle String?
final
passPrice String?
final
passShowPrice String?
final
passShowSubTitle String?
final
passShowValidity String?
final
passSubTitle String?
final
passTitle String?
final
passWithBarcode String?
final
passWithQrcode String?
final
premiumQuotas → dynamic
final
premiumQuotasPeriod → dynamic
final
promotionActive int?
final
promotionCondition String?
final
promotionCumulable int?
final
promotionDateEnd String?
final
promotionDateStart String?
final
promotionDesc String?
final
promotionDiscount String?
final
promotionDiscountType int?
final
promotionIcon String?
final
promotionId int?
final
promotionReducceType String?
final
final
promotionSource int?
final
promotionStores String?
final
promotionTitle String?
final
promotionType String?
final
promotionWay String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stockMin int?
final
updatedAt String?
final
uploadedPdf List<UploadedPdf>?
final
useCodes int?
final
webScan int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited