PromotionPartner class

Annotations
  • @JsonSerializable.new()

Constructors

PromotionPartner({required int? partnerId, required String? partnerName, required String? promotionTitle, required String? discount, required int? discountType, required String? promotionType, required String? promotionDiscountType, required int? scanCount, required String? privilegeTypeName, required String? privilegeTypeIcon, required String? promotionIcon, required String? promotionReducceType, required String? promotionDiscount})
PromotionPartner.fromJson(Map<String, dynamic> json)
factory

Properties

discount String?
final
discountType int?
final
hashCode int
The hash code for this object.
no setterinherited
partnerId int?
final
final
partnerName String?
final
privilegeTypeIcon String?
final
privilegeTypeName String?
final
promotionDiscount String?
final
promotionDiscountType String?
final
promotionIcon String?
final
promotionReducceType String?
final
promotionTitle String?
final
promotionType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanCount int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited