ProfileRemoteDataSource class abstract

Implementers

Constructors

ProfileRemoteDataSource()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAccount(DeleteAccountRequest deleteAccountRequest) Future<AppResponse<String?>>
getClient() Future<AppResponse<Client>>
getPromotionHistory(HistoryRequest? historyRequest) Future<AppResponse<PromotionPassHistoryResponse>>
getPromotionPassHistory(HistoryRequest? historyRequest) Future<AppResponse<PromotionPassHistoryResponse>>
logout() Future<AppResponse<String?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateClient(UpdateClientRequest request) Future<AppResponse<Client>>

Operators

operator ==(Object other) bool
The equality operator.
inherited