ProfileRemoteDataSourceImpl class

Implemented types

Constructors

ProfileRemoteDataSourceImpl({required PrefUtils prefUtils, required ApiClient apiClient})

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
prefUtils PrefUtils
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAccount(DeleteAccountRequest deleteAccountRequest) Future<AppResponse<String?>>
override
getClient() Future<AppResponse<Client>>
override
getPromotionHistory(HistoryRequest? historyRequest) Future<AppResponse<PromotionPassHistoryResponse>>
override
getPromotionPassHistory(HistoryRequest? historyRequest) Future<AppResponse<PromotionPassHistoryResponse>>
override
logout() Future<AppResponse<String?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateClient(UpdateClientRequest request) Future<AppResponse<Client>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited