Client class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Client({int? clientId, String? clientFirstName, String? clientLast, String? clientPhoneNumber, String? clientGender, int? clientAge, int? clientActive, String? clientPhoneId, int? clientPhoneOs, int? countryId, int? clientStore, String? source, String? clientAuth, String? entryBy, String? clientEmail, int? clientCity, dynamic subStore, dynamic subStoreEndDate, dynamic tpvPreferences, dynamic authProvider, dynamic authProviderId, int? isConnect, dynamic avatar, dynamic externalId, dynamic deviceId, int? activeSubscription, int? clientSubscribed, String? clientOperator, int? subStoreExpired, String? subscriptionType, bool? isPremium, Store? store, List<Login>? login, String? emailVerifiedAt, bool? receiveNotificationAcceptation, String? city, String? postalCode, String? birthDate, String? address})
Client.fromJson(Map<String, dynamic> json)
factory

Properties

activeSubscription int?
final
address String?
final
authProvider → dynamic
final
authProviderId → dynamic
final
avatar → dynamic
final
birthDate String?
final
city String?
final
clientActive int?
final
clientAge int?
final
clientAuth String?
final
clientCity int?
final
clientEmail String?
final
clientFirstName String?
final
clientGender String?
final
clientId int?
final
clientLast String?
final
clientOperator String?
final
clientPhoneId String?
final
clientPhoneNumber String?
final
clientPhoneOs int?
final
clientStore int?
final
clientSubscribed int?
getter/setter pair
countryId int?
final
deviceId → dynamic
final
emailVerifiedAt String?
final
entryBy String?
final
externalId → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
isConnect int?
final
isPremium bool?
final
login List<Login>?
final
postalCode String?
final
receiveNotificationAcceptation bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final
store Store?
final
subscriptionType String?
final
subStore → dynamic
final
subStoreEndDate → dynamic
final
subStoreExpired int?
final
tpvPreferences → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited