GetOrdersResponse class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GetOrdersResponse({required String? orderNumber, required String? typeBillet, required String? barcode, required String? info, required String? data, required String? statusCode, required String? status, required String? etatsStatut, required String? statusGetBillets, required String? createdAt, required String? partnerName})
GetOrdersResponse.fromJson(Map<String, dynamic> json)
factory

Properties

barcode String?
final
createdAt String?
final
data String?
final
etatsStatut String?
final
hashCode int
The hash code for this object.
no setterinherited
info String?
final
orderNumber String?
final
partnerName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
statusCode String?
final
statusGetBillets String?
final
typeBillet String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited