Login class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Login({int? id, int? clientId, String? deviceId, String? os, String? source, String? lastLoginMethod})
Login.fromJson(Map<String, dynamic> json)
factory

Properties

clientId int?
final
deviceId String?
final
hashCode int
The hash code for this object.
no setterinherited
id int?
final
lastLoginMethod String?
final
os String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited