UpdateClientRequest class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

UpdateClientRequest({required String? clientFirstName, required String? clientLast, required String? clientPhoneNumber, required bool? receiveNotificationAcceptation})
UpdateClientRequest.fromJson(Map<String, dynamic> json)
factory

Properties

clientFirstName String?
final
clientLast String?
final
clientPhoneNumber String?
final
hashCode int
The hash code for this object.
no setterinherited
receiveNotificationAcceptation bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited