EditUserDataWidget class

Inheritance

Constructors

EditUserDataWidget({Key? key, required dynamic edit(UpdateClientRequest request), required TextEditingController controllerFirstName, required TextEditingController controllerLastName, required TextEditingController controllerEmail, required TextEditingController controllerPhone, required bool isChecked, required dynamic onCheck(bool)})
const

Properties

controllerEmail TextEditingController
final
controllerFirstName TextEditingController
final
controllerLastName TextEditingController
final
controllerPhone TextEditingController
final
edit → dynamic Function(UpdateClientRequest request)
final
hashCode int
The hash code for this object.
no setterinherited
isChecked bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCheck → dynamic Function(bool)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<EditUserDataWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited