SubscriptionRemoteDataSource class abstract

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanPromotion(ScanRequest request) Future<AppResponse<List<ScanResponse>>>
subscribe(SubscribeRequest request) Future<AppResponse<List>>
toString() String
A string representation of this object.
inherited
unsubscribe() Future<AppResponse<List>>

Operators

operator ==(Object other) bool
The equality operator.
inherited