ScanResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ScanResponse({required int? promotionId, required String? partnerName, required String promotionTitle, required String? promotionDiscount, required int? useCodes, required String? promotionDateEnd, required String? qrCode, required int? displayCode, required String? expired})
ScanResponse.fromJson(Map<String, dynamic> json)
factory

Properties

displayCode int?
final
expired String?
final
hashCode int
The hash code for this object.
no setterinherited
partnerName String?
final
promotionDateEnd String?
final
promotionDiscount String?
final
promotionId int?
final
promotionTitle String
final
qrCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useCodes int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited