SubscribeRequest class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SubscribeRequest({required int priceId, String? giftCard, required int subscriptionId, String? packageName, String? productId, String? purchaseToken})
SubscribeRequest.fromJson(Map<String, dynamic> json)
factory

Properties

giftCard String?
final
hashCode int
The hash code for this object.
no setterinherited
packageName String?
final
priceId int
final
productId String?
final
purchaseToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited