S class

Constructors

S()

Properties

cancel String
cancel
no setter
close String
close
no setter
conditions String
Conditions
no setter
confirm String
confirm
no setter
congratulations String
congratulations
no setter
create_account String
create account
no setter
dont_have_account String
dont have account
no setter
email String
email
no setter
forget_password String
forget_password
no setter
hashCode int
The hash code for this object.
no setterinherited
info String
Info
no setter
language String
English
no setter
login String
login
no setter
name_can_only_contain_alphabetic_characters String
name can only contain alphabetic characters
no setter
near_me String
Near me
no setter
news String
News
no setter
password String
password
no setter
password_must_be_at_least String
password must be at least
no setter
password_must_be_content String
The password must contain lowercase letters, uppercase letters, and numbers.
no setter
passwords_do_not_match String
passwords do not match
no setter
please_confirm_the_password String
please confirm the password
no setter
please_enter_a_first_and_last_name String
please enter a first name
no setter
please_enter_a_password String
please enter a password
no setter
please_enter_a_phone_number String
please enter a phone number
no setter
please_enter_a_valid_email_address String
please enter a valid email address
no setter
please_enter_a_valid_phone_number String
please enter a valid phone number
no setter
please_enter_a_valid_zip_code String
please enter a valid zip code
no setter
please_enter_a_zip_code String
please enter a zip code
no setter
please_enter_an_email_address String
please enter an email address
no setter
please_fill_in_the_required_field String
please fill in the required field
no setter
privileges String
Privileges
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scan_the_code String
Scan the code
no setter
setting String
Setting
no setter
voucher String
Voucher
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current S
no setter

Static Methods

load(Locale locale) Future<S>
maybeOf(BuildContext context) S?
of(BuildContext context) S

Constants

delegate → const AppLocalizationDelegate