PrefUtilsImpl class
- Implemented types
Constructors
- PrefUtilsImpl({})
Properties
- clientKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFirstTimeKey → String
-
final
- pagesKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- storeTokenKey → String
-
final
- subscriptionKey → String
-
final
- tokenKey → String
-
final
Methods
-
getClient(
) → Client? -
override
-
getIsFirstTime(
) → bool -
override
-
getPages(
) → List< PageResponse> ? -
override
-
getStoreToken(
) → String -
override
-
getSubscriptions(
) → List< Subscription> ? -
override
-
getToken(
) → String -
override
-
logout(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeClient(
) → void -
override
-
removeIsFirstTime(
) → void -
override
-
removePages(
) → void -
override
-
removeStoreToken(
) → void -
override
-
removeSubscriptions(
) → void -
override
-
removeToken(
) → void -
override
-
setClient(
Client? client) → void -
override
-
setIsFirstTime(
bool isFirstTime) → void -
override
-
setPages(
List< PageResponse> ? pages) → void -
override
-
setStoreToken(
String token) → void -
override
-
setSubscriptions(
List< Subscription> ? subscriptions) → void -
override
-
setToken(
String token) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited