ClientDetails class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ClientDetails({required int clientId, required String clientTelephone, required int clientActive, required String clientPhoneId, required String clientPhoneOs, required int countryId, required int clientStore, required String createdAt, required String updatedAt, required int isConnect, required int activeSubscription, required int clientSubscribed, required String clientOperator, required int subStoreExpired, required String subscriptionType, required bool isPremium, required Store store})
-
ClientDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeSubscription → int
-
final
- clientActive → int
-
final
- clientId → int
-
final
- clientOperator → String
-
final
- clientPhoneId → String
-
final
- clientPhoneOs → String
-
final
- clientStore → int
-
final
- clientSubscribed → int
-
final
- clientTelephone → String
-
final
- countryId → int
-
final
- createdAt → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnect → int
-
final
- isPremium → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → Store
-
final
- subscriptionType → String
-
final
- subStoreExpired → int
-
final
- updatedAt → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited