RegisterRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- RegisterRequest({required String clientFirstName, required String clientEmail, required String password, required String clientPhoneId, required String clientPhoneOs, required String receiveNotificationAcceptation})
-
RegisterRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- clientEmail → String
-
final
- clientFirstName → String
-
final
- clientPhoneId → String
-
final
- clientPhoneOs → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- password → String
-
final
- receiveNotificationAcceptation → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited