PartnerRequest class
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- PartnerRequest({required String? categoryType, required String? promotionType, int? perPage, int? category, int? page})
-
PartnerRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- category → int?
-
final
- categoryType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int?
-
final
- perPage → int?
-
final
- promotionType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited