S class
Constructors
- S()
Properties
- cancel → String
-
cancelno setter - close → String
-
closeno setter - conditions → String
-
Conditionsno setter - confirm → String
-
confirmno setter - congratulations → String
-
congratulationsno setter - create_account → String
-
create accountno setter - dont_have_account → String
-
dont have accountno setter - email → String
-
emailno setter - forget_password → String
-
forget_passwordno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- info → String
-
Infono setter - language → String
-
Englishno setter - login → String
-
loginno setter - name_can_only_contain_alphabetic_characters → String
-
name can only contain alphabetic charactersno setter - near_me → String
-
Near meno setter - news → String
-
Newsno setter - password → String
-
passwordno setter - password_must_be_at_least → String
-
password must be at leastno setter - password_must_be_content → String
-
The password must contain lowercase letters, uppercase letters, and numbers.no setter - passwords_do_not_match → String
-
passwords do not matchno setter - please_confirm_the_password → String
-
please confirm the passwordno setter - please_enter_a_first_and_last_name → String
-
please enter a first nameno setter - please_enter_a_password → String
-
please enter a passwordno setter - please_enter_a_phone_number → String
-
please enter a phone numberno setter - please_enter_a_valid_email_address → String
-
please enter a valid email addressno setter - please_enter_a_valid_phone_number → String
-
please enter a valid phone numberno setter - please_enter_a_valid_zip_code → String
-
please enter a valid zip codeno setter - please_enter_a_zip_code → String
-
please enter a zip codeno setter - please_enter_an_email_address → String
-
please enter an email addressno setter - please_fill_in_the_required_field → String
-
please fill in the required fieldno setter - privileges → String
-
Privilegesno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scan_the_code → String
-
Scan the codeno setter - setting → String
-
Settingno setter - voucher → String
-
Voucherno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
Locale locale) → Future< S> -
maybeOf(
BuildContext context) → S? -
of(
BuildContext context) → S
Constants
- delegate → const AppLocalizationDelegate